/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.aws.iot.pubsub;

import javax.net.ssl.SSLContext;

/**
 * This class represents the connection options of an AWS IoT Thing, needed to
 * connect to the platform.
 */
public class ConnectOptions {

	private String serverHost;

	private int serverPort;

	private String thingId;

	private SSLContext sslContext;

	/**
	 * Gets the serverHost.
	 *
	 * @return the serverHost.
	 */
	public String getServerHost() {
		return this.serverHost;
	}

	/**
	 * Sets the serverHost.
	 *
	 * @param serverHost
	 *            the serverHost to set.
	 * @return the current instance of the options
	 */
	public ConnectOptions setServerHost(String serverHost) {
		this.serverHost = serverHost;
		return this;
	}

	/**
	 * Gets the serverPort.
	 *
	 * @return the serverPort.
	 */
	public int getServerPort() {
		return this.serverPort;
	}

	/**
	 * Sets the serverPort.
	 *
	 * @param serverPort
	 *            the serverPort to set.
	 * @return the current instance of the options
	 */
	public ConnectOptions setServerPort(int serverPort) {
		this.serverPort = serverPort;
		return this;
	}

	/**
	 * Gets the thingId.
	 *
	 * @return the thingId.
	 */
	public String getThingId() {
		return this.thingId;
	}

	/**
	 * Sets the thingId.
	 *
	 * @param thingId
	 *            the thingId to set.
	 * @return the current instance of the options
	 */
	public ConnectOptions setThingId(String thingId) {
		this.thingId = thingId;
		return this;
	}

	/**
	 * Gets the sslContext.
	 *
	 * @return the sslContext.
	 */
	public SSLContext getSslContext() {
		return this.sslContext;
	}

	/**
	 * Sets the sslContext.
	 *
	 * @param sslContext
	 *            the sslContext to set.
	 * @return the current instance of the options
	 */
	public ConnectOptions setSslContext(SSLContext sslContext) {
		this.sslContext = sslContext;
		return this;
	}

	/**
	 * Builds the server address.
	 *
	 * @return the correctly formatted server address
	 */
	public String buildServerAddress() {
		return "ssl://" + this.serverHost + ":" + this.serverPort;
	}
}
