/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.zwave.device;

import java.io.IOException;

import ej.basedriver.MultilevelSensor;
import ej.basedriver.MultilevelValue;
import ej.basedriver.zwave.ZwaveNode;
import ej.basedriver.zwave.ZwaveProtocol;
import ej.basedriver.zwave.frame.SendData;
import ej.basedriver.zwave.frame.SendDataListener;
import ej.basedriver.zwave.util.NumberUtil;

/**
 *
 */
public class ZwaveMultilevelSensor extends ZwaveDevice implements MultilevelSensor, SendDataListener {

	private double value;

	/**
	 * @param node
	 */
	public ZwaveMultilevelSensor(ZwaveNode node) {
		super(node);
		this.value = MultilevelValue.UNKNOWN;
		try {
			requestUpdate();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	/**
	 * Sets the value.
	 *
	 * @param value
	 *            the value to set.
	 */
	public void setValue(double value) {
		if (this.value != value) {
			this.value = value;
			try {
				node.getController().getListener().onEvent(MultilevelSensor.class, this);
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
	}

	@Override
	public double getLastKnownValue() {
		return value;
	}

	@Override
	public void requestUpdate() throws IOException {
		SendData frame = new SendData(this, ZwaveProtocol.COMMAND_CLASS_SENSOR_MULTILEVEL,
				ZwaveProtocol.SENSOR_MULTILEVEL_GET);
		node.getController().sendFrame(frame);
	}

	@Override
	public void notifyComplete() {
		// TODO Auto-generated method stub

	}

	@Override
	public void notifyError(RequestFrameError error) {
		try {
			node.getController().getListener().onError(MultilevelSensor.class, this);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	@Override
	public ZwaveNode getNode() {
		return node;
	}

	@Override
	public void callbackComplete(byte[] bytes, int commandClassIndex) {
		byte command = bytes[commandClassIndex + 1];
		if (command == ZwaveProtocol.SENSOR_MULTILEVEL_REPORT) {
			int precision = ((bytes[commandClassIndex + 3] & 0b11100000) >> 5);
			int size = (bytes[commandClassIndex + 3] & 0b00000111);

			setValue(NumberUtil.readDouble(bytes, commandClassIndex + 4, size, precision));
		}
	}
}
