/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.zwave.frame;

import java.io.IOException;

import ej.basedriver.zwave.Session;
import ej.basedriver.zwave.ZwaveController;
import ej.basedriver.zwave.ZwaveNode;
import ej.basedriver.zwave.ZwaveProtocol;
import ej.basedriver.zwave.util.BitArray;

public class GetInitialData extends RequestFrame {
	private static final int SIZE_INDEX = 6;

	/**
	 * @param listener
	 */
	public GetInitialData(RequestFrameListener listener) {
		super(listener, ZwaveProtocol.FUNC_ID_SERIAL_API_GET_INIT_DATA);
	}

	@Override
	public synchronized void handleResponse(ZwaveController controller,
			DataFrame dataFrame) throws IOException {
		super.handleResponse(controller, dataFrame);

		byte [] bytes = dataFrame.getBytes();
		byte size = bytes [SIZE_INDEX];
		int start = SIZE_INDEX + 1;
		BitArray bitArray = new BitArray(bytes, start, size);
		for (int cpt = 0; cpt < size * 8; cpt++) {
			if (bitArray.testBit(cpt)) {
				if (controller.getId() != (cpt + 1)) {
					controller.sendFrame(new NodeProtocolInfo(controller, new ZwaveNode(controller, (byte) (cpt+1))));
				}
			}
		}
	}

	@Override
	public Session getSession() {
		return Session.RESPONSE;
	}
}
