/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.components.dependencyinjection;

import java.io.IOException;
import java.io.InputStream;

/**
 *
 */
public class MetaInfServiceLoader extends AbstractServiceLoader {

	private static final String PREFIX = "/META-INF/services/"; //$NON-NLS-1$

	/**
	 * Creates a new META-INF properties service loader.
	 */
	public MetaInfServiceLoader() {
		super();
	}

	@Override
	protected String getImplementationName(String key) {
		String serviceFileName = PREFIX + key;
		try (InputStream inputStream = MetaInfServiceLoader.class.getResourceAsStream(serviceFileName)) {
			while (true) {
				// read line
				StringBuilder lineBuilder = new StringBuilder();
				while (true) {
					int readByte = inputStream.read();
					if (readByte == -1 || readByte == '\n') {
						// end of file or end of line
						break;
					} else {
						lineBuilder.append((char) readByte);
					}
				}
				String line = lineBuilder.toString().trim();
				if (!line.isEmpty() && line.charAt(0) != '#') {
					// read only first valid line
					return line;
				}
			}
		} catch (IOException | NullPointerException e) {
			// cannot read file
		}
		return null;
	}

}
