/*
 * Java
 *
 * Copyright 2016-2017 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.data.channel;

/**
 * A {@link DataChannel} provider.
 */
public interface DataChannelProvider {

	/**
	 * Returns the identifier of the provider.
	 * It is preferable, although not required, that the returned string should be printable.
	 *
	 * @return the provider identifier
	 */
	public String getID();

	/**
	 * Creates a new {@link DataChannel} with the given name. The mapping is implementation dependent.
	 * For example, the channel name can serve to generate a file (<code>[path]/[name]</code>), or an URI (<code>https://myserver/api/[name]</code>) or a MQTT topic (<code>/prefix/[name]</code>).
	 * @param name the channel simple name. Only alphanumeric characters, <code>-</code>, <code>_</code> and <code>/</code> are allowed.
	 * @return null if the channel cannot be created.
	 */
	public DataChannel newChannel(String name);
}
