/*
 * Java
 *
 * Copyright 2018 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.firmwareupdate;

import java.io.IOException;

/**
 * A class can implement the {@link IFirmwareProgrammer} interface when it wants to be able to do program a new
 * firmware.
 */
public interface IFirmwareProgrammer {

	/**
	 * Initialize a firmware update procedure.
	 *
	 * @throws IOException
	 *             If I/O error occurred
	 */
	public void initialize() throws IOException;

	/**
	 * Writes a chunk of firmware data as part of the firmware update.
	 *
	 * @param data
	 *            firmware data chunk
	 * @param offset
	 *            offset in the array
	 * @param length
	 *            number of bytes to write
	 * @throws IOException
	 *             If I/O error occurred
	 */
	public void write(byte[] data, int offset, int length) throws IOException;

	/**
	 * Finishes the firmware update procedure.
	 *
	 * @throws IOException
	 *             If I/O error occurred
	 */
	public void finish() throws IOException;

	/**
	 * Reset the firmware.
	 *
	 * @throws IOException
	 *             If I/O error occurred
	 */
	public void reset() throws IOException;

}
