/*
 * Java
 *
 * Copyright 2016 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.giml.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import javax.annotation.processing.SupportedSourceVersion;
import javax.lang.model.SourceVersion;

/**
 * An annotation to tag element (i.e. objects have their own GIML tag).
 */
@SupportedSourceVersion(SourceVersion.RELEASE_7)
@Target(ElementType.TYPE)
@Retention(RetentionPolicy.SOURCE)
public @interface Element {
	/**
	 * The tag name of this element. Empty name means to use the element class name as tag name.
	 *
	 * @return the tag name of this element.
	 */
	public String name() default "";

	/**
	 * Defines if this element is a GIML root (i.e. is in top level of GIML files).
	 *
	 * @return {@code true} if this element is a GIML root, {@code false} otherwise.
	 */
	public boolean root() default false;

	/**
	 * The friendly name of this element. Empty friendly name means to use the tag name.
	 *
	 * @return the friendly name of this element.
	 * @see #name()
	 */
	public String friendlyName() default "";

	/**
	 * The description of this element. Empty description means a default one.
	 *
	 * @return the description of this element.
	 */
	public String description() default "";
}
