# Overview

This addon library provides tools to enforce an access control policy.

Currently, it provides an ACL implementation.

# Usage

## Setup

Add the following line to your `module.ivy` or your `ivy.xml`:
> `<dependency org="ej.library.iot" name="access-control" rev="..."/>`

## ACL example

First, instantiate the policy engine and add user permissions on the object `safe` (any Java object) :

```java
AccessControlList acl = new AccessControlList();

acl.add("root", safe, "read", "write");
acl.add("admin", safe, "read");
```

Then, query the engine to enforce the policy :

```java
acl.isAuthorized("user", safe, "read"); // false
acl.isAuthorized("admin", safe, "read"); // true
acl.isAuthorized("admin", safe, "write"); // false
acl.isAuthorized("root", anotherObject, "write"); // false
```

By default, the permissions are stored in an in-memory thread-safe database (non-persistent). To change this behavior, pass an instance of another implementation into the `AccessControlList` constructor :

```java
AccessControlList acl = new AccessControlList(new AclDataAccess() {
    @Override
    void add(String user, String action, Object resource) {
        // TODO: add the permission to the database
    }
    @Override
    AclEntry getEntry(String user, Object resource) {
        // TODO: retrieve the permissions for user on resource
    }
});
```

# Requirements

This library requires the following Foundation Libraries:

    BON-1.3, EDC-1.2

# Dependencies
_All dependencies are retrieved transitively by Ivy resolver_.

# Source
N/A

# Restrictions
None.

---
_Copyright 2019 MicroEJ Corp. All rights reserved._
_This library is provided in source code for use, modification and test, subject to license terms._
_Any modification of the source code will break MicroEJ Corp. warranties on the whole library._
