# Overview

This library enables MicroEJ developers to access the AWS IoT platform, providing publish/subscribe functionalities.
To get started add the following lines in the `module.ivy` of your project :
	
    <dependency org="ej.library.iot.aws" name="aws-iot" rev="1.2.0"/>

# Usage

## Connect to the broker

The first thing to do is representing the device using the class `Thing`.

### Provide the connect options

The class `ConnectOptions` contains all the elements the client needs to establish a connection with the broker.
Give it your broker address, broker port and thing id before trying to call the connect function.
Also, the AWS ioT platform requires TLS mutual authentication using a valid certificate and its key.
You have to provide an SSL context as well to the `ConnectOptions`.

```java
ConnectOptions options = new ConnectOptions().setServerHost(SERVER_HOST).setServerPort(SERVER_PORT)
		.setThingId(THING_ID).setSslContext(sslContextHelper.getSslContext());
```

### Open the connection

You can then open a connection with the broker using :

```java
Thing myThing = new Thing(options);
myThing.connect();
```

## Publish a message

A message can be published to a desired topic like this :

```java
String topic = "mytopic";
myThing.publish(topic, "{\"test\":\"1234 56789\"}".getBytes());
```

Note that the QoS used is 0.

## Subscribe to a topic

In order to subscribe to a topic, you need to create a class implementing the interface `ej.aws.iot.pubsub.TopicListener` and adding it to your`Thing`.
If you want your program to execute any business logic when a message is received on the topic, be sure to add it to the `onDataReceived(String topic, byte[] dataReceived)` function, which will be called automatically when a message arrives on the topic.


```java
sslContextHelper = new SslContextHelper();

ConnectOptions options = new ConnectOptions().setServerHost(SERVER_HOST).setServerPort(SERVER_PORT)
		.setThingId(THING_ID).setSslContext(sslContextHelper.getSslContext());

Client client = new Client();

client.connect(options);

client.addTopicListener("9876", new TopicListener() {

	@Override
	public void onDataReceived(String topic, byte[] dataReceived) {

		String expectedTopic = "9876";

		if (expectedTopic.equals(topic)) {

			String dataReceivedString = new String(dataReceived);

			assertTrue(dataReceivedString.equals("test"));
		}
	}
});
```

# Requirements

This library requires the following Foundation Libraries:

    BON-1.3, EDC-1.2, NET-1.1, SSL-2.1

# Dependencies

_All dependencies are retrieved transitively by MicroEJ Module Manager_.

# Source

N/A

# Restrictions

None.

---  
_Markdown_  
_Copyright 2017-2019 MicroEJ Corp. All rights reserved._  
_This library is provided in source code for use, modification and test, subject to license terms._  
_Any modification of the source code will break MicroEJ Corp. warranties on the whole library._  