/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.cascading;

import ej.style.Style;

/*package*/class CascadingStyle extends Style {

	private static final int INHERIT_MASK = (0x1 << FOREGROUND_COLOR_SHIFT) | (0x1 << FONT_PROFILE_SHIFT)
			| (0x1 << ALIGNMENT_SHIFT) | (0x1 << TEXT_MANAGER_SHIFT);

	CascadingStyle() {
	}

	CascadingStyle(Style style) {
		super(style);
	}

	/**
	 * Fills all missing attributes of this style with those in the given style.
	 */
	boolean merge(CascadingStyle style) {
		// All isSet… methods are inlined for performance purpose.
		int map = this.map;
		int styleMap = style.map;
		int computedMap = ~map & styleMap;
		if ((computedMap & (0x1 << FOREGROUND_COLOR_SHIFT)) != 0x0) {
			this.foregroundColor = style.foregroundColor;
		}
		if ((computedMap & (0x1 << BACKGROUND_COLOR_SHIFT)) != 0x0) {
			this.backgroundColor = style.backgroundColor;
		}
		if ((computedMap & (0x1 << BORDER_COLOR_SHIFT)) != 0x0) {
			this.borderColor = style.borderColor;
		}
		if ((computedMap & (0x1 << BORDER_SHIFT)) != 0x0) {
			this.border = style.border;
		}
		if ((computedMap & (0x1 << FONT_PROFILE_SHIFT)) != 0x0) {
			this.fontProfile = style.fontProfile;
		}
		if ((computedMap & (0x1 << ALIGNMENT_SHIFT)) != 0x0) {
			this.alignment = style.alignment;
		}
		if ((computedMap & (0x1 << TEXT_MANAGER_SHIFT)) != 0x0) {
			this.textManager = style.textManager;
		}
		if ((computedMap & (0x1 << DIMENSION_SHIFT)) != 0x0) {
			this.dimension = style.dimension;
		}
		if ((computedMap & (0x1 << PADDING_SHIFT)) != 0x0) {
			this.padding = style.padding;
		}
		if ((computedMap & (0x1 << MARGIN_SHIFT)) != 0x0) {
			this.margin = style.margin;
		}
		if ((computedMap & (0x1 << BACKGROUND_SHIFT)) != 0x0) {
			this.background = style.background;
		}
		this.map |= styleMap;
		return this.map == Style.COMPLETE_MAP;
	}

	/**
	 * Fills all missing attributes of this style with the inherited ones from the given style.
	 */
	boolean inheritMerge(CascadingStyle parentStyle) {
		// All isSet… methods are inlined for performance purpose.
		int map = this.map;
		int styleMap = parentStyle.map;
		int computedMap = ~map & styleMap;
		if ((computedMap & (0x1 << FOREGROUND_COLOR_SHIFT)) != 0x0) {
			this.foregroundColor = parentStyle.foregroundColor;
		}
		if ((computedMap & (0x1 << FONT_PROFILE_SHIFT)) != 0x0) {
			this.fontProfile = parentStyle.fontProfile;
		}
		if ((computedMap & (0x1 << ALIGNMENT_SHIFT)) != 0x0) {
			this.alignment = parentStyle.alignment;
		}
		if ((computedMap & (0x1 << TEXT_MANAGER_SHIFT)) != 0x0) {
			this.textManager = parentStyle.textManager;
		}
		this.map |= styleMap & INHERIT_MASK;
		return (this.map & INHERIT_MASK) == INHERIT_MASK;
	}

}
