/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.selector;

import ej.annotation.Nullable;
import ej.style.Element;
import ej.style.Selector;
import ej.style.registry.ElementRegistry;

/**
 * An ID selector selects by checking if the element is registered in {@link ElementRegistry}.
 * <p>
 * Equivalent to <code>#id</code> selector in CSS. Its specificity is (0,1,0,0).
 *
 * @see SpecificityHelper
 */
public class IDSelector implements Selector {

	private final String id;

	/**
	 * Creates an ID selector.
	 *
	 * @param id
	 *            the ID to check.
	 */
	public IDSelector(String id) {
		this.id = id;
	}

	@Override
	public boolean fit(Element element) {
		return element == ElementRegistry.requestElement(this.id);
	}

	@Override
	public int getSpecificity() {
		return SpecificityHelper.getSpecificity(0, 1, 0, 0);
	}

	@Override
	public int hashCode() {
		return this.id.hashCode();
	}

	@Override
	public boolean equals(@Nullable Object obj) {
		if (obj instanceof IDSelector) {
			return ((IDSelector) obj).id == this.id;
		}
		return false;
	}

}
