/*
 * Java
 *
 * Copyright 2017-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.util.property;

/**
 *
 */
public class CompositePropertyLoader implements PropertyLoader {

	/**
	 * Ordered array of property loader to look-up into.
	 */
	protected PropertyLoader[] propertyLoaders;

	/**
	 * Instantiates and fills a composite property loader with various implementations.
	 *
	 * @param propertyLoaders
	 *            array of implementations of PropertyLoader.
	 */
	public CompositePropertyLoader(PropertyLoader[] propertyLoaders) {
		this.propertyLoaders = propertyLoaders;
	}

	@Override
	public String getProperty(String key) {
		return this.getProperty(key, null);
	}

	@Override
	public String getProperty(String key, String defaultValue) {
		for (PropertyLoader propertyLoader : this.propertyLoaders) {
			String value = propertyLoader.getProperty(key);
			if (null != value) {
				return value;
			}
		}
		return defaultValue;
	}
}
