/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.wadapps.registry.util;

import java.util.Dictionary;
import java.util.Hashtable;

import ej.components.dependencyinjection.util.ServiceLoaderHelper;
import ej.wadapps.registry.SharedRegistry;

/**
 * This class is the default implementation of the shared registry.
 */
public class SharedRegistryImpl implements SharedRegistry {

	private final Dictionary<Class<?>, Object> services;

	/**
	 * Creates a new shared registry implementation.
	 */
	protected SharedRegistryImpl() {
		this.services = new Hashtable<>(2);
	}

	@Override
	public <T> T getService(Class<T> service) {
		return getService(service, true);
	}

	@Override
	public <T> T getService(Class<T> service, boolean singleton) {
		if (!singleton) {
			return null;
		}
		// cast for sure, see #register(Class<T>, T)
		@SuppressWarnings("unchecked")
		T implementation = (T) this.services.get(service);
		return implementation;
	}

	@Override
	public <T> T getService(Class<T> service, Class<? extends T> defaultImplementation) {
		return getService(service, defaultImplementation, true);
	}

	@Override
	public <T> T getService(Class<T> service, Class<? extends T> defaultImplementation, boolean singleton) {
		Dictionary<Class<?>, Object> services = this.services;
		if (singleton) {
			@SuppressWarnings("unchecked")
			T implementation = (T) this.services.get(service); // cast ensured
																// by
																// construction
																// (see put()
																// call)
			if (implementation != null) {
				return implementation;
			}
		}

		if (defaultImplementation == null) {
			return null;
		}
		String implementationName = defaultImplementation.getName();

		T serviceImplementation = ServiceLoaderHelper.createClassInstance(service, implementationName);
		if (singleton) {
			this.services.put(service, serviceImplementation);
		}
		return serviceImplementation;
	}

	@Override
	public <T> void register(Class<T> service, T implementation) {
		this.services.put(service, implementation);
	}

	@Override
	public <T> void unregister(Class<T> service, T implementation) {
		T registeredImplementation = getService(service);
		if (registeredImplementation == implementation) {
			this.services.remove(service);
		}
	}

}
