/*
 * Java
 *
 * Copyright 2017-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.widget.animation;

import ej.mwt.Widget;

/**
 * An animation step listener is notified for each step of an animation. It also receives the animation parameters when
 * the animation is started.
 */
public interface AnimationStepListener {

	/**
	 * An animation is starting with the given properties.
	 * <p>
	 * The {@link #onStep(int)} method will be called with a value between the given start and stop. Whatever the way
	 * (forward or backward), this value goes from start to stop.
	 *
	 * @param start
	 *            the animation start value.
	 * @param stop
	 *            the animation stop value.
	 * @param from
	 *            the widget before the animation.
	 * @param to
	 *            the widget after the animation.
	 * @param forward
	 *            <code>true</code> if going forward, <code>false</code> otherwise.
	 */
	void initialize(int start, int stop, Widget from, Widget to, boolean forward);

	/**
	 * A step of an animation is done.
	 *
	 * @param value
	 *            the step value.
	 */
	void onStep(int value);

}
