/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.widget.basic.picto;

import ej.microui.display.Font;
import ej.microui.display.GraphicsContext;
import ej.style.Style;
import ej.style.container.Rectangle;
import ej.style.util.StyleHelper;
import ej.widget.basic.AbstractProgress;
import ej.widget.model.BoundedRangeModel;
import ej.widget.model.DefaultBoundedRangeModel;

/**
 * A progress using some pictos to render.
 */
public class PictoProgress extends AbstractProgress {

	private static final int PROGRESS_STEP_COUNT = 10;

	private int indeterminateStep;

	/**
	 * Creates a progress bar with the given model.
	 *
	 * @param model
	 *            the model to use.
	 */
	public PictoProgress(BoundedRangeModel model) {
		super(model);
	}

	/**
	 * Creates a progress bar with a default bounded range model as model.
	 *
	 * @param min
	 *            the minimum value of the progress bar.
	 * @param max
	 *            the maximum value of the progress bar.
	 * @param initialValue
	 *            the initial value of the progress bar.
	 * @see DefaultBoundedRangeModel
	 */
	public PictoProgress(int min, int max, int initialValue) {
		super(min, max, initialValue);
	}

	@Override
	public void renderContent(GraphicsContext g, Style style, Rectangle bounds) {
		g.setColor(style.getForegroundColor());
		g.setFont(StyleHelper.getFont(style));
		g.drawChar(getPicto(), bounds.getWidth() >> 1, bounds.getHeight() >> 1,
				GraphicsContext.HCENTER | GraphicsContext.VCENTER);
	}

	private char getPicto() {
		if (isIndeterminate()) {
			if (++this.indeterminateStep == PROGRESS_STEP_COUNT) {
				this.indeterminateStep = 0;
			}
			return getIndeterminatePicto();
		} else {
			return getProgressPicto(getPercentComplete());
		}
	}

	@Override
	public Rectangle validateContent(Style style, Rectangle bounds) {
		Font font = StyleHelper.getFont(style);
		int width = font.charWidth(getPicto());
		int height = font.getHeight();
		return new Rectangle(0, 0, width, height);
	}

	private char getProgressPicto(float percentComplete) {
		int step = Math.round(percentComplete * PROGRESS_STEP_COUNT);
		return (char) (Pictos.PROGRESS_0 + step);
	}

	private char getIndeterminatePicto() {
		return (char) (Pictos.PROGRESS_INDETERMINATE_0 + this.indeterminateStep);
	}

	@Override
	protected void indeterminateTick() {
		super.indeterminateTick();

		repaint();
	}

}
